import warnings

from nr.stream import Supplier  # For backwards compatibility with kraken-core<=0.10.13

from .system.task_supplier import TaskSupplier

Empty = Supplier.Empty  # For backwards compatibility with kraken-core<=0.10.13

warnings.warn(
    "The `kraken.core.supplier` module is deprecated; you should import only public API from `kraken.core.api` instead.",  # noqa: E501
    DeprecationWarning,
)

__all__ = [
    "Empty",
    "Supplier",
    "TaskSupplier",
]



import warnings

from .testing import kraken_ctx, kraken_project

warnings.warn(
    "The `kraken.core.test` module is deprecated; you should import testing fixtures from `kraken.core.testing` instead.",  # noqa: E501
    DeprecationWarning,
)

__all__ = [
    "kraken_ctx",
    "kraken_project",
]



import warnings

from .system.task import (
    BackgroundTask,
    GroupTask,
    Task,
    TaskRelationship,
    TaskSet,
    TaskSetPartitions,
    TaskSetSelect,
    TaskStatus,
    TaskStatusType,
    VoidTask,
)

warnings.warn(
    "The `kraken.core.task` module is deprecated; you should import only public API from `kraken.core.api` instead.",
    DeprecationWarning,
)

__all__ = [
    "TaskStatusType",
    "TaskStatus",
    "Task",
    "GroupTask",
    "VoidTask",
    "BackgroundTask",
    "TaskSet",
    "TaskSetSelect",
    "TaskSetPartitions",
    "TaskRelationship",
]



import warnings

from .system.property import Object, Property, PropertyConfig, PropertyDescriptor

warnings.warn(
    "The `kraken.core.property` module is deprecated; you should import only public API from `kraken.core.api` instead.",  # noqa: E501
    DeprecationWarning,
)

__all__ = [
    "Object",
    "Property",
    "PropertyConfig",
    "PropertyDescriptor",
]



"""
This module exports the public API of the Kraken build system.

Users of Kraken should only import from this module.
"""

from kraken.core.system.context import Context, ContextEvent
from kraken.core.system.project import Project, ProjectLoaderError
from kraken.core.system.property import Property
from kraken.core.system.task import (
    BackgroundTask,
    GroupTask,
    Task,
    TaskRelationship,
    TaskSet,
    TaskStatus,
    TaskStatusType,
    VoidTask,
)

__all__ = [
    "BackgroundTask",
    "Context",
    "ContextEvent",
    "GroupTask",
    "Project",
    "ProjectLoaderError",
    "Property",
    "Task",
    "TaskRelationship",
    "TaskSet",
    "TaskStatus",
    "TaskStatusType",
    "VoidTask",
]



import warnings

from .system.graph import TaskGraph, _Edge

warnings.warn(
    "The `kraken.core.graph` module is deprecated; you should import only public API from `kraken.core.api` instead.",
    DeprecationWarning,
)

__all__ = [
    "_Edge",
    "TaskGraph",
]



import warnings
from pathlib import Path

from .system.executor import Graph, GraphExecutor, GraphExecutorObserver

warnings.warn(
    "The `kraken.core.executor` module is deprecated; you should import only public API from `kraken.core.api` instead.",  # noqa: E501
    DeprecationWarning,
)

__all__ = [
    "Graph",
    "GraphExecutor",
    "GraphExecutorObserver",
]

# For full backwards compatibility, we'll allow importing the submodules of the original package here.
__path__ = [str(Path(__file__).parent / "system" / "executor")]



import warnings

from .system.project import Project, ProjectLoaderError

warnings.warn(
    "The `kraken.core.project` module is deprecated; you should import only public API from `kraken.core.api` instead.",
    DeprecationWarning,
)

__all__ = [
    "ProjectLoaderError",
    "Project",
]



__version__ = "0.11.4"

# NOTE(NiklasRosenstein): Imports from `kraken.core` directly are deprecated; instead you should import
#   from `kraken.core.api`. This file will not be updated until the next release with breaking changes
#   which will completely clear the contents of the module.

from nr.stream import Supplier

from kraken.core.system.context import BuildError, Context, ContextEvent
from kraken.core.system.executor import Graph, GraphExecutor, GraphExecutorObserver
from kraken.core.system.graph import TaskGraph
from kraken.core.system.project import Project, ProjectLoaderError
from kraken.core.system.property import Property
from kraken.core.system.task import (
    BackgroundTask,
    GroupTask,
    Task,
    TaskRelationship,
    TaskSet,
    TaskStatus,
    TaskStatusType,
    VoidTask,
)

__all__ = [
    "BackgroundTask",
    "BuildError",
    "Context",
    "ContextEvent",
    "Graph",
    "GraphExecutor",
    "GraphExecutorObserver",
    "GroupTask",
    "Project",
    "ProjectLoaderError",
    "Property",
    "Supplier",
    "Task",
    "TaskGraph",
    "TaskRelationship",
    "TaskSet",
    "TaskStatus",
    "TaskStatusType",
    "VoidTask",
]



import warnings

from .system.context import BuildError, Context, ContextEvent, ContextEventType

warnings.warn(
    "The `kraken.core.context` module is deprecated; you should import only public API from `kraken.core.api` instead.",
    DeprecationWarning,
)

__all__ = [
    "Context",
    "BuildError",
    "ContextEvent",
    "ContextEventType",
]
